@@ -1,3 +1,5 @@
+import logging
+
 from aiogram import Dispatcher
 from aiogram import types
 from aiogram.dispatcher import FSMContext
@@ -38,19 +40,6 @@ class MessageView(BaseView):
     async def execute(cls, m: types.Message, state: FSMContext = None, **kwargs):
         raise NotImplementedError
 
-    @classmethod
-    async def _execute(cls, m: types.Message, state: FSMContext = None, **kwargs):
-        chat_type = m.chat.type
-        if not hasattr(cls, f'execute_in_{chat_type}'):
-            await cls.execute(m, state, **kwargs)
-            return
-
-        method = cls.__dict__[f'execute_in_{chat_type}']
-        if isinstance(method, classmethod):
-            await method.__func__(cls, m, state, **kwargs)
-        else:
-            await method.__func__(m, state, **kwargs)
-
     @classmethod
     def register(cls, dp: Dispatcher):
         """method to register the handler, normally called automatically in manage.initialize_project()
